<?php
// +----------------------------------------------------------------------
// | likeshop开源商城系统
// +----------------------------------------------------------------------
// | 欢迎阅读学习系统程序代码，建议反馈是我们前进的动力
// | gitee下载：https://gitee.com/likeshop_gitee
// | github下载：https://github.com/likeshop-github
// | 访问官网：https://www.likeshop.cn
// | 访问社区：https://home.likeshop.cn
// | 访问手册：http://doc.likeshop.cn
// | 微信公众号：likeshop技术社区
// | likeshop系列产品在gitee、github等公开渠道开源版本可免费商用，未经许可不能去除前后端官方版权标识
// |  likeshop系列产品收费版本务必购买商业授权，购买去版权授权后，方可去除前后端官方版权标识
// | 禁止对系统程序代码以任何目的，任何形式的再发布
// | likeshop团队版权所有并拥有最终解释权
// +----------------------------------------------------------------------
// | author: likeshop.cn.team
// +----------------------------------------------------------------------

namespace app\admin\controller\shop;


use app\admin\logic\shop\GoodsLogic;
use app\common\basics\AdminBase;
use app\common\server\JsonServer;

/**
 * 主营类目
 * Class Category
 * @package app\admin\controller\shop
 */
class Goods extends AdminBase
{
    /**
     * NOTE: 主营类目列表
     * @author: 张无忌
     */
    public function lists()
    {
        if ($this->request->isAjax()) {
            $get = $this->request->get();
            $lists = GoodsLogic::lists($get);
            return JsonServer::success('获取成功', $lists);
        }
        
        return view();
    }

    /**
     * NOTE: 新增主营类目
     * @author: 张无忌
     */
    public function add()
    {
        if ($this->request->isAjax()) {
            $post = $this->request->post();
            if(!isset($post['image']) || empty($post['image'])) {
                return JsonServer::error('类目图标不能为空');
            }

            //验证
            if($post['pc_num'] <= 0){
                return JsonServer::error('PC数量必须为正整数');
            }
            if($post['mobile_num'] <= 0){
                return JsonServer::error('手机设备必须为正整数');
            }
            if($post['run_num'] <= 0){
                return JsonServer::error('同时运行设备数必须为正整数');
            }

            $res = GoodsLogic::add($post);
            if ($res === false) {
                $error = GoodsLogic::getError() ?: '新增失败';
                return JsonServer::error($error);
            }
            return JsonServer::success('新增成功');
        }

        return view();
    }

    /**
     * NOTE: 编辑主营类目
     * @author: 张无忌
     */
    public function edit()
    {
        if ($this->request->isAjax()) {
            $post = $this->request->post();
            if(!isset($post['image']) || empty($post['image'])) {
                return JsonServer::error('类目图标不能为空');
            }
            $res = GoodsLogic::edit($post);
            if ($res === false) {
                $error = GoodsLogic::getError() ?: '编辑失败';
                return JsonServer::error($error);
            }
            return JsonServer::success('编辑成功');
        }

        $id = $this->request->get('id');
        return view('', [
            'detail' => GoodsLogic::detail($id)
        ]);
    }

    /**
     * NOTE: 删除主营类目
     * @author: 张无忌
     */
    public function del()
    {
        if ($this->request->isAjax()) {
            $id = $this->request->post('id');
            $res = GoodsLogic::del($id);
            if ($res === false) {
                $error = GoodsLogic::getError() ?: '删除失败';
                return JsonServer::error($error);
            }
            return JsonServer::success('删除成功');
        }

        return JsonServer::error('请求异常');
    }
}