<?php
// +----------------------------------------------------------------------
// | likeshop开源商城系统
// +----------------------------------------------------------------------
// | 欢迎阅读学习系统程序代码，建议反馈是我们前进的动力
// | gitee下载：https://gitee.com/likeshop_gitee
// | github下载：https://github.com/likeshop-github
// | 访问官网：https://www.likeshop.cn
// | 访问社区：https://home.likeshop.cn
// | 访问手册：http://doc.likeshop.cn
// | 微信公众号：likeshop技术社区
// | likeshop系列产品在gitee、github等公开渠道开源版本可免费商用，未经许可不能去除前后端官方版权标识
// |  likeshop系列产品收费版本务必购买商业授权，购买去版权授权后，方可去除前后端官方版权标识
// | 禁止对系统程序代码以任何目的，任何形式的再发布
// | likeshop团队版权所有并拥有最终解释权
// +----------------------------------------------------------------------
// | author: likeshop.cn.team
// +----------------------------------------------------------------------

namespace app\admin\logic\shop;


use app\common\basics\Logic;

use app\common\model\shop\Shop; //判断是否绑定
//use app\common\model\shop\ShopApply;  //判断是否绑定

use app\common\model\shop\ShopGoods;
use Exception;

class GoodsLogic extends Logic
{
    /**
     * NOTE: 主营类目列表
     * @author: 张无忌
     * @param $get
     * @return array|bool
     */
    public static function lists($get)
    {
        try {
            $where = [
                ['del', '=', 0]
            ];

            if (!empty($get['name']) and $get['name'])
                $where[] = ['name', 'like', '%'.$get['name'].'%'];

            $model = new ShopGoods();
            $lists = $model->field(true)
                ->where($where)
                ->order('sort', 'desc')
                ->paginate([
                    'page'      => $get['page'],
                    'list_rows' => $get['limit'],
                    'var_page' => 'page'
                ])
                ->toArray();

            return ['count'=>$lists['total'], 'lists'=>$lists['data']];
        } catch (Exception $e) {
            return ['error'=>$e->getMessage()];
        }
    }

    /**
     * NOTE: 主营类目详细
     * @author: 张无忌
     * @param $id
     * @return array
     */
    public static function detail($id)
    {
        $model = new ShopGoods();
        return $model->field(true)->findOrEmpty((int)$id)->toArray();
    }

    /**
     * NOTE: 获取主营类目
     * @author: 张无忌
     * @return array
     */
    public static function getCategory()
    {
        try {
            $model = new ShopGoods();
            return $model->field(true)
                ->where('del', 0)
                ->order('id', 'desc')
                ->order('sort', 'desc')
                ->select()->toArray();
        } catch (\Exception $e) {
            return [];
        }
    }

    /**
     * NOTE: 新增主营类目
     * @author: 张无忌
     * @param $post
     * @return bool
     */
    public static function add($post)
    {
        try {
            ShopGoods::create([
                'name'  => $post['name'],
                'price'  => $post['price'],
                'desc'  => $post['desc'],
                'pc_num'  => $post['pc_num'],
                'mobile_num'  => $post['mobile_num'],
                'run_num'  => $post['run_num'],
                'image' => $post['image'] ?? '',
                'sort'  => $post['sort'] ?? 0
            ]);

            return true;
        } catch (Exception $e) {
            static::$error = $e->getMessage();
            return false;
        }
    }

    /**
     * NOTE: 编辑主营类目
     * @author: 张无忌
     * @param $post
     * @return bool
     */
    public static function edit($post)
    {
        try {
            ShopGoods::update([
                'name'  => $post['name'],
                'price'  => $post['price'],
                'desc'  => $post['desc'],
                'pc_num'  => $post['pc_num'],
                'mobile_num'  => $post['mobile_num'],
                'run_num'  => $post['run_num'],
                'image' => $post['image'] ?? '',
                'sort'  => $post['sort'] ?? 0
            ], ['id'=>(int)$post['id']]);

            return true;
        } catch (Exception $e) {
            static::$error = $e->getMessage();
            return false;
        }
    }

    /**
     * NOTE: 删除主营类目
     * @author: 张无忌
     * @param $id
     * @return bool
     */
    public static function del($id)
    {
        try {
            $shopModel      = new Shop();
            //$shopApplyModel = new ShopApply();

            $shop  = $shopModel->where(['tid'=>(int)$id, 'del'=>0])->findOrEmpty()->toArray();
            //$apply = $shopApplyModel->where(['cid'=>(int)$id, 'del'=>0])->findOrEmpty()->toArray();
            $apply = false;

            if ($shop or $apply) {
                static::$error = '类目已被使用,不允许删除';
                return false;
            }

            ShopGoods::update([
                'del'         => 1,
                'create_time' => time()
            ], ['id'=>(int)$id]);

            return true;
        }  catch (Exception $e) {
            static::$error = $e->getMessage();
            return false;
        }
    }
}