<?php
/*
 * @Author: ZMH
 * @Email: zmhwork@qq.com
 * @Date: 2025-03-13 11:47:30
 * @LastEditTime: 2025-03-14 18:02:56
 * @LastEditors: xiaohai zmhwork@qq.com
 * @FilePath: \opkpm\app\admin\logic\shop\GoodsRenewLogic.php
 * 
 * @Description: 续费逻辑处理
 */

namespace app\admin\logic\shop;

use app\admin\validate\shop\GoodsRenewValidate;
use app\common\basics\Logic;

use app\common\model\shop\Shop; //判断是否绑定

use app\common\model\shop\ShopGoodsRenew;
use Exception;

class GoodsRenewLogic extends Logic
{
    public static function lists($get)
    {
        $where = [
            ['del', '=', 0]
        ];

        if (!empty($get['name']) && $get['name'])
            $where[] = ['name', 'like', '%' . $get['name'] . '%'];

        $model = new ShopGoodsRenew();
        $lists = $model->field(true)
            ->where($where)
            ->order('sort', 'desc')
            ->paginate([
                'page'      => $get['page'],
                'list_rows' => $get['limit'],
                'var_page' => 'page'
            ])
            ->toArray();
        foreach ($lists['data'] as $key => $value) {
            $lists['data'][$key]['type_str'] = $value['type_id'] == 0 ? '包月' : '按量付费';
            $lists['data'][$key]['status_str'] = $value['status'] == 0 ? '禁用' : '启用';
        }

        return ['count' => $lists['total'], 'lists' => $lists['data']];
    }

    public static function detail($id)
    {
        $model = new ShopGoodsRenew();
        return $model->field(true)->findOrEmpty((int)$id)->toArray();
    }

    public static function getCategory()
    {
        try {
            $model = new ShopGoodsRenew();
            return $model->field(true)
                ->where('del', 0)
                ->order('id', 'desc')
                ->order('sort', 'desc')
                ->select()->toArray();
        } catch (\Exception $e) {
            return [];
        }
    }

    public static function add($post)
    {
        try {
            validate(GoodsRenewValidate::class)->scene('add')->check($post);
        } catch (Exception $e) {
            static::$error = $e->getMessage();
            return false;
        }

        ShopGoodsRenew::create($post);

        return true;
    }

    public static function edit($post)
    {
        try {
            validate(GoodsRenewValidate::class)->scene('edit')->check($post);
        } catch (Exception $e) {
            static::$error = $e->getMessage();
            return false;
        }

        $info = ShopGoodsRenew::where("id", $post['id'])->find();
        if (!$info) {
            static::$error = '数据不存在';
            return false;
        }

        $info->save($post);

        return true;
    }

    public static function del($post)
    {
        try {
            validate(GoodsRenewValidate::class)->scene('edit')->check($post);
        } catch (Exception $e) {
            static::$error = $e->getMessage();
            return false;
        }

        $info = ShopGoodsRenew::where("id", $post['id'])->find();
        if (!$info) {
            static::$error = '数据不存在';
            return false;
        }

        $info->del = 1;
        $info->save();

        return true;
    }
}
